@@ -122,6 +122,8 @@ class GraphWrapQuery:
             edgeInfo={}
             tailInfo={}
         
+        headInfo["case_sensitive"]=headInfo.get("case_sensitive",False)
+        
         if "direct" not in edgeInfo and len(edgeInfo)>0:
             edgeInfo["direct"]=""
         
@@ -135,41 +137,51 @@ class GraphWrapQuery:
         # LOOKUP语句构建
         if head==True:
             
-            if len(headInfo.get("nodeIdVal_fuzzy",""))>0:
+            if len(headInfo.get("nodeIdVal_fuzzy",""))>0 or headInfo["case_sensitive"]==True:
+                queryName=headInfo["nodeIdVal_fuzzy"] if len(headInfo.get("nodeIdVal_fuzzy",""))>0 else headInfo["nodeIdVal"]
+                
                 if self.esClient!=None:
                     qbody={
                             "query":{
                                 "bool":{
-                                    "should":[
-                                        {"match":{
-                                            "Name.keyword": {
-                                                "query": headInfo["nodeIdVal_fuzzy"],  
-                                                "fuzziness": "AUTO",
-                                                "prefix_length": 0,
-                                                "max_expansions":1,
-                                                "boost":10
+                                    "must":[
+                                        {
+                                            "bool":{
+                                                "should":[
+                                                    {"match":{
+                                                        "Name" if headInfo["case_sensitive"]==False else "Name.keyword": {
+                                                            "query": queryName,  
+                                                            "fuzziness": "AUTO",
+                                                            "prefix_length": 1,
+                                                            "boost":10
+                                                        }
+                                                    }},
+                                                    {"match": {
+                                                        "AliasNames" if headInfo["case_sensitive"]==False else "AliasNames.keyword": {
+                                                            "query": queryName,
+                                                            "fuzziness": "AUTO",
+                                                            "prefix_length": 1,
+                                                            "boost":1
+                                                        }
+                                                    }}
+                                                ]
                                             }
-                                        }},
-                                        {"match": {
-                                            "AliasNames.keyword": {
-                                                "query": headInfo["nodeIdVal_fuzzy"],
-                                                "fuzziness": "AUTO",
-                                                "prefix_length": 0,
-                                                "max_expansions":1,
-                                                "boost":1
-                                            }
-                                        }}
+                                         }
                                     ]
                                 }
                             }
                         }
                     if len(headInfo.get("nodeType",""))>0:
                         nodeTypeESJudgeJson={
-                            "term":{
-                                "gTagName":headInfo["nodeType"]
+                            "bool":{
+                                "must":{
+                                    "term":{
+                                        "gTagName":headInfo["nodeType"]
+                                    }
+                                }
                             }
                         }
-                        qbody["query"]["bool"]["must"]=qbody["query"]["bool"].get("must",[])+[nodeTypeESJudgeJson]
+                        qbody["query"]["bool"]["must"]=qbody["query"]["bool"]["must"]+[nodeTypeESJudgeJson]
                     
                         
                     esResult=self.esClient.search(index=self.esIndex,body=qbody,timeout='60s')["hits"]["hits"]
@@ -189,6 +201,7 @@ class GraphWrapQuery:
                             headInfo["nodeType"]=esResult[0]["_source"]["gTagName"]
                             headInfo["nodeIdAttr"]=keyItem
             
+            
             if headInfo["nodeIdVal"]!="*":
                 singleQueryStrList=["LOOKUP ON {nodeType} WHERE {nodeType}.{nodeIdAttr}=='{nodeIdVal}'|\
                                             YIELD $-.VertexID AS src{nodeType}SysId".format(
@@ -575,58 +588,58 @@ if __name__=="__main__":
     # )
     # myGQuery.renew()
     
-    # wrapJson2Qeury-1
-    queryJson={
-            "searchMethod":"seqSearch",
-            "searchFrame":[
-                {
-                    "searchMethod":"singleSearch",
-                    "searchFrame":{
-                        "head":{
-                            "nodeType":"Company",
-                            "nodeIdAttr":"CompanyName",
-                            "nodeIdVal":"深圳市腾讯计算机系统有限公司"
-                        },
-                        "edge":{
-                            "edgeType":"produce"
-                        },
-                        "tail":{
-                            "nodeType":"Product",
-                            "nodeIdAttr":"ProductName",
-                            "nodeIdVal":None
-                        },
-                        "singleYieldList":[
-                            {"nodeType":"Company","nodeAttr":"CompanyName"},
-                            {"nodeType":"Product","nodeAttr":"ProductName"}
-                        ]
-                    }
-                },{
-                    "searchMethod":"singleSearch",
-                    "searchFrame":{
-                        "head":{
-                            "nodeType":"Product",
-                            "nodeIdAttr":"ProductName",
-                            "nodeIdVal":None
-                        },
-                        "edge":{
-                            "edgeType":"belongTo"
-                        },
-                        "tail":{
-                            "nodeType":"Field",
-                            "nodeIdAttr":"FieldName",
-                            "nodeIdVal":None
-                        },
-                        "singleYieldList":[
-                            {"nodeType":"Company","nodeAttr":"CompanyName"},
-                            {"nodeType":"Product","nodeAttr":"ProductName"},
-                            {"nodeType":"Field","nodeAttr":"FieldName"}
-                        ]
-                    }
-                }
-            ]
-        }
-    queryFunc=myGQuery.wrapJson2Query(queryJson)
-    queryStr=myGQuery.runWaitFunc(queryFunc)
+    # # wrapJson2Qeury-1
+    # queryJson={
+    #         "searchMethod":"seqSearch",
+    #         "searchFrame":[
+    #             {
+    #                 "searchMethod":"singleSearch",
+    #                 "searchFrame":{
+    #                     "head":{
+    #                         "nodeType":"Company",
+    #                         "nodeIdAttr":"CompanyName",
+    #                         "nodeIdVal":"深圳市腾讯计算机系统有限公司"
+    #                     },
+    #                     "edge":{
+    #                         "edgeType":"produce"
+    #                     },
+    #                     "tail":{
+    #                         "nodeType":"Product",
+    #                         "nodeIdAttr":"ProductName",
+    #                         "nodeIdVal":None
+    #                     },
+    #                     "singleYieldList":[
+    #                         {"nodeType":"Company","nodeAttr":"CompanyName"},
+    #                         {"nodeType":"Product","nodeAttr":"ProductName"}
+    #                     ]
+    #                 }
+    #             },{
+    #                 "searchMethod":"singleSearch",
+    #                 "searchFrame":{
+    #                     "head":{
+    #                         "nodeType":"Product",
+    #                         "nodeIdAttr":"ProductName",
+    #                         "nodeIdVal":None
+    #                     },
+    #                     "edge":{
+    #                         "edgeType":"belongTo"
+    #                     },
+    #                     "tail":{
+    #                         "nodeType":"Field",
+    #                         "nodeIdAttr":"FieldName",
+    #                         "nodeIdVal":None
+    #                     },
+    #                     "singleYieldList":[
+    #                         {"nodeType":"Company","nodeAttr":"CompanyName"},
+    #                         {"nodeType":"Product","nodeAttr":"ProductName"},
+    #                         {"nodeType":"Field","nodeAttr":"FieldName"}
+    #                     ]
+    #                 }
+    #             }
+    #         ]
+    #     }
+    # queryFunc=myGQuery.wrapJson2Query(queryJson)
+    # queryStr=myGQuery.runWaitFunc(queryFunc)
     
     # # wrapJson2Qeury-2
     # queryJson={
@@ -655,52 +668,52 @@ if __name__=="__main__":
     # queryStr=myGQuery.runWaitFunc(queryFunc)
     
     # wrapJson2Query-seq
-    queryJson={
-        "searchMethod":"seqSearch",
-        "searchFrame":[
-            {
-                "searchMethod":"singleSearch",
-                "searchFrame":{
-                    "head":{
-                        "nodeType":"YunPost",
-                        "nodeIdAttr":"YunPostName",
-                        "nodeIdVal":"*"
-                    },
-                    "edge":{
-                        "edgeType":"subPost"
-                    },
-                    "tail":{
-                        "nodeType":"YunPost",
-                        "nodeIdAttr":"YunPostName",
-                        "nodeIdVal":None
-                    },
-                    "singleYieldList":[
-                        {"nodeType":"YunPost","nodeAttr":"YunPostName"}
-                    ]
-                }
-            },{
-                "searchMethod":"singleSearch",
-                "searchFrame":{
-                    "head":{
-                        "nodeType":"YunPost",
-                        "nodeIdAttr":"YunPostName",
-                        "nodeIdVal":None
-                    },
-                    "edge":{
-                        "edgeType":"subPost"
-                    },
-                    "tail":{
-                        "nodeType":"YunPost",
-                        "nodeIdAttr":"YunPostName",
-                        "nodeIdVal":None
-                    },
-                    "singleYieldList":[
-                        {"nodeType":"YunPost","nodeAttr":"YunPostName"}
-                    ]
-                }
-            }
-        ]
-    }
+    # queryJson={
+    #     "searchMethod":"seqSearch",
+    #     "searchFrame":[
+    #         {
+    #             "searchMethod":"singleSearch",
+    #             "searchFrame":{
+    #                 "head":{
+    #                     "nodeType":"YunPost",
+    #                     "nodeIdAttr":"YunPostName",
+    #                     "nodeIdVal":"*"
+    #                 },
+    #                 "edge":{
+    #                     "edgeType":"subPost"
+    #                 },
+    #                 "tail":{
+    #                     "nodeType":"YunPost",
+    #                     "nodeIdAttr":"YunPostName",
+    #                     "nodeIdVal":None
+    #                 },
+    #                 "singleYieldList":[
+    #                     {"nodeType":"YunPost","nodeAttr":"YunPostName"}
+    #                 ]
+    #             }
+    #         },{
+    #             "searchMethod":"singleSearch",
+    #             "searchFrame":{
+    #                 "head":{
+    #                     "nodeType":"YunPost",
+    #                     "nodeIdAttr":"YunPostName",
+    #                     "nodeIdVal":None
+    #                 },
+    #                 "edge":{
+    #                     "edgeType":"subPost"
+    #                 },
+    #                 "tail":{
+    #                     "nodeType":"YunPost",
+    #                     "nodeIdAttr":"YunPostName",
+    #                     "nodeIdVal":None
+    #                 },
+    #                 "singleYieldList":[
+    #                     {"nodeType":"YunPost","nodeAttr":"YunPostName"}
+    #                 ]
+    #             }
+    #         }
+    #     ]
+    # }
     # queryFunc=myGQuery.wrapJson2Query(queryJson)
     # queryStr=myGQuery.runWaitFunc(queryFunc)
     
@@ -722,21 +735,24 @@ if __name__=="__main__":
     # queryFunc=myGQuery.wrapJson2Query(queryJson)
     # queryStr=myGQuery.runWaitFunc(queryFunc)
     
-    # # fuzzy search
-    # queryJson={
-    #     "searchMethod":"singleSearch",
-    #     "searchFrame":{
-    #         "head":{
-    #             "nodeIdVal_fuzzy":"深圳市腾讯计算机系统有限公司"
-    #         },
-    #         "singleYieldList":[
-    #             {"nodeType":"Company","nodeAttr":"CompanyName"},
-    #             {"nodeType":"Company","nodeAttr":"AliasNames"}
-    #         ]
-    #     }
-    # }
-    # queryFunc=myGQuery.wrapJson2Query(queryJson)
-    # queryStr=myGQuery.runWaitFunc(queryFunc)
+    # fuzzy search
+    queryJson={
+        "searchMethod":"seqSearch",
+        "searchFrame":[
+            {
+                "searchMethod":"singleSearch",
+                "searchFrame":{
+                    "head":{
+                        "nodeType":"Company",
+                        "nodeIdAttr":"CompanyName",
+                        "nodeIdVal_fuzzy":"ge工作室"
+                    }
+                }
+            }
+        ]
+    }
+    queryFunc=myGQuery.wrapJson2Query(queryJson)
+    queryStr=myGQuery.runWaitFunc(queryFunc)
     
     print(queryStr)
     print(123)
